@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-# Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
+# Copyright (c) 2008-2025, Jesús Cea Avión <jcea@jcea.es>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -36,6 +36,7 @@
 import os
 import re
 import sys
+import platform
 
 
 # See https://setuptools.readthedocs.io/en/latest/deprecated/\
@@ -121,7 +122,6 @@ if os.name == 'posix':
         db_inc_paths = []
         db_major = set()
         bitness = ""
-        import platform
         if (platform.architecture()[0] == "64bit") and \
            (platform.platform(True, True).startswith("Solaris-")) and \
            (not platform.uname()[3].startswith('joyent_')):
@@ -161,8 +161,9 @@ if os.name == 'posix':
             lib_dirs = compiler.library_dirs + [
                 '/lib64', '/usr/lib64',
                 '/lib', '/usr/lib',
-                '/usr/lib/x86_64-linux-gnu/',
+                # More directories added later if compiling on Linux
             ]
+
             inc_dirs = compiler.include_dirs + [
                 '/usr/include', '/usr/local/opt/berkeley-db/include',
             ]
@@ -224,14 +225,38 @@ if os.name == 'posix':
                         ('db-%d.%d' % db_ver),
                         ('db%d' % db_ver[0])
                         ):
-                    dblib_file = compiler.find_library_file(
-                                    db_dirs_to_check + lib_dirs, dblib )
-                    if dblib_file:
-                        db_libdir = os.path.abspath(os.path.dirname(dblib_file))
+
+                    if platform.system() == 'Linux':
+                        import ctypes.util
+                        import subprocess
+
+                        # If you think this code is ugly, just check
+                        # "ctypes.util.find_library()" and cry.
+
+                        dblib_file = ctypes.util.find_library(dblib)
+                        if not dblib_file:
+                            continue
+                        expr = re.escape(dblib_file)
+                        expr = re.compile(f'^\\s*{expr}[^/]*(/.*)/{expr}$',
+                                          flags=re.M)
+                        ldconfig = subprocess.run(['/sbin/ldconfig', '-p'],
+                                                  check=True, timeout=5,
+                                                  capture_output=True,
+                                                  text=True)
+                        ldconfig = expr.search(ldconfig.stdout)
+                        if not ldconfig:
+                            continue
+                        db_libdir = ldconfig[1]
                         raise db_found
                     else:
-                        if debug:
-                            print("db lib: ", dblib, "not found")
+                        dblib_file = compiler.find_library_file(
+                                        db_dirs_to_check + lib_dirs, dblib )
+                        if dblib_file:
+                            db_libdir = os.path.abspath(os.path.dirname(dblib_file))
+                            raise db_found
+                        else:
+                            if debug:
+                                print("db lib: ", dblib, "not found")
         except db_found:
             print("Found Oracle Berkeley DB %d.%d installation." % db_ver)
             print("  include files in", db_incdir)
